{% set breadcrumbs = lineage(context)|reverse %}
{% if  breadcrumbs|length > 2 %}
    <div class="nav">
        {% for crumb in breadcrumbs %}
            {% if crumb.node %}
                {% if not loop.last %}
                    <a href="{{ request.resource_url(crumb.resource_of_node(crumb.node)) }}"
                       class="nav__link">{{ crumb.name }}</a>
                    <span href="#" class="nav__separator"><i class="fa fa-chevron-right">&nbsp;</i></span>
                {% else %}
                    <div class="nav__link">{{ crumb.name }}</div>
                {% endif %}
            {% endif %}
        {% endfor %}
    </div>
{% endif %}
